@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,9 +32,10 @@
 #include <Collection>
 #include <CollectionModifyJob>
 #include <EntityDisplayAttribute>
-#include <AkonadiCore/NewMailNotifierAttribute>
+#include <Akonadi/KMime/NewMailNotifierAttribute>
 #include <KIdentityManagement/IdentityCombo>
 #include <PimCommonAkonadi/ImapResourceCapabilitiesManager>
+#include <Libkdepim/LineEditCatchReturnKey>
 
 #include <KColorScheme>
 #include <KLineEdit>
@@ -50,11 +52,6 @@ using namespace MailCommon;
 
 CollectionGeneralPage::CollectionGeneralPage(QWidget *parent)
     : CollectionPropertiesPage(parent)
-    , mContentsComboBox(nullptr)
-    , mIncidencesForComboBox(nullptr)
-    , mSharedSeenFlagsCheckBox(nullptr)
-    , mNameEdit(nullptr)
-    , mFolderCollection(nullptr)
 {
     setObjectName(QStringLiteral("MailCommon::CollectionGeneralPage"));
     setPageTitle(i18nc("@title:tab General settings for a folder.", "General"));
@@ -92,10 +89,10 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
         label = new QLabel(i18nc("@label:textbox Name of the folder.", "&Name:"), this);
         hl->addWidget(label);
 
-        mNameEdit = new KLineEdit(this);
-        mNameEdit->setTrapReturnKey(true);
+        mNameEdit = new QLineEdit(this);
+        new KPIM::LineEditCatchReturnKey(mNameEdit, this);
 
-        connect(mNameEdit, &KLineEdit::textChanged, this, &CollectionGeneralPage::slotNameChanged);
+        connect(mNameEdit, &QLineEdit::textChanged, this, &CollectionGeneralPage::slotNameChanged);
         label->setBuddy(mNameEdit);
         hl->addWidget(mNameEdit);
     }
@@ -313,7 +310,7 @@ void CollectionGeneralPage::save(Collection &collection)
     if (mIncidencesForComboBox && mIncidencesForComboBox->isEnabled()) {
         annotations[ PimCommon::CollectionTypeUtil::kolabIncidencesFor() ]
             = collectionUtil.incidencesForToString(
-            static_cast<PimCommon::CollectionTypeUtil::IncidencesFor>(mIncidencesForComboBox->currentIndex())).toLatin1();
+                  static_cast<PimCommon::CollectionTypeUtil::IncidencesFor>(mIncidencesForComboBox->currentIndex())).toLatin1();
     }
 
     if (mContentsComboBox) {
