@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,13 +17,14 @@
 
 #include "filteractionaddtoaddressbooktest.h"
 #include "../filteractions/filteractionaddtoaddressbook.h"
-#include <qtest.h>
+#include <QTest>
 #include <QWidget>
 #include <QLabel>
-#include <klineedit.h>
-#include <pimcommon/minimumcombobox.h>
-#include <libkdepimakonadi/tagwidgets.h>
+#include <KLineEdit>
+#include <QComboBox>
+
 #include <AkonadiWidgets/CollectionComboBox>
+#include <AkonadiWidgets/TagWidget>
 
 FilterActionAddToAddressBookTest::FilterActionAddToAddressBookTest(QObject *parent)
     : QObject(parent)
@@ -39,13 +40,13 @@ void FilterActionAddToAddressBookTest::shouldHaveDefaultValue()
     MailCommon::FilterActionAddToAddressBook filter;
     QWidget *w = filter.createParamWidget(nullptr);
 
-    PimCommon::MinimumComboBox *headerCombo = w->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("HeaderComboBox"));
+    auto headerCombo = w->findChild<QComboBox *>(QStringLiteral("HeaderComboBox"));
     QVERIFY(headerCombo);
 
     QLabel *label = w->findChild<QLabel *>(QStringLiteral("label_with_category"));
     QVERIFY(label);
 
-    KPIM::TagWidget *categoryEdit = w->findChild<KPIM::TagWidget *>(QStringLiteral("CategoryEdit"));
+    auto categoryEdit = w->findChild<Akonadi::TagWidget *>(QStringLiteral("CategoryEdit"));
     QVERIFY(categoryEdit);
 
     label = w->findChild<QLabel *>(QStringLiteral("label_in_addressbook"));
@@ -63,7 +64,7 @@ void FilterActionAddToAddressBookTest::shouldReportErrorWhenArgumentIsEmpty()
     item.setPayload<KMime::Message::Ptr>(msgPtr);
     MailCommon::ItemContext context(item, false);
 
-    filter.argsFromString("");
+    filter.argsFromString(QString());
     QVERIFY(filter.isEmpty());
     QCOMPARE(filter.process(context, false), MailCommon::FilterAction::ErrorButGoOn);
     QCOMPARE(context.needsPayloadStore(), false);
@@ -79,7 +80,7 @@ void FilterActionAddToAddressBookTest::shouldReportErrorWhenCollectionIsInvalid(
     item.setPayload<KMime::Message::Ptr>(msgPtr);
     MailCommon::ItemContext context(item, false);
 
-    filter.argsFromString("foo\t-1\tddd");
+    filter.argsFromString(QStringLiteral("foo\t-1\tddd"));
     QVERIFY(filter.isEmpty());
     QCOMPARE(filter.process(context, false), MailCommon::FilterAction::ErrorButGoOn);
     QCOMPARE(context.needsPayloadStore(), false);
