@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@
 
 #include "filteractioncopytest.h"
 #include "../filteractions/filteractioncopy.h"
-#include <qtest.h>
+#include <QTest>
 
 FilterActionCopyTest::FilterActionCopyTest(QObject *parent)
     : QObject(parent)
