@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -37,7 +37,7 @@ FilterActionMissingIdentityDialog::FilterActionMissingIdentityDialog(const QStri
     : QDialog(parent)
 {
     setModal(true);
-    setWindowTitle(i18n("Select Identity"));
+    setWindowTitle(i18nc("@title:window", "Select Identity"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     QLabel *label = new QLabel(this);
