@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,7 +35,7 @@ FilterActionMissingTransportDialog::FilterActionMissingTransportDialog(const QSt
     : QDialog(parent)
 {
     setModal(true);
-    setWindowTitle(i18n("Select Transport"));
+    setWindowTitle(i18nc("@title:window", "Select Transport"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     QLabel *label = new QLabel(this);
