@@ -19,15 +19,16 @@
 
 #include "filteractionaddtoaddressbook.h"
 
-#include "PimCommon/MinimumComboBox"
+#include <Akonadi/Contact/AddContactJob>
 
-#include <LibkdepimAkonadi/AddContactJob>
-#include <LibkdepimAkonadi/TagWidgets>
+#include <AkonadiWidgets/TagSelectionDialog>
+#include <AkonadiWidgets/TagWidget>
 
 #include <CollectionComboBox>
 #include <KContacts/Addressee>
 #include <KLocalizedString>
 #include <KEmailAddress>
+#include <KComboBox>
 
 #include <QGridLayout>
 #include <QLabel>
@@ -98,7 +99,7 @@ FilterAction::ReturnCode FilterActionAddToAddressBook::process(ItemContext &cont
             contact.setCategories(mCategory.split(QLatin1Char(';')));
         }
 
-        KPIM::AddContactJob *job = new KPIM::AddContactJob(contact, Akonadi::Collection(mCollectionId));
+        Akonadi::AddContactJob *job = new Akonadi::AddContactJob(contact, Akonadi::Collection(mCollectionId));
         job->showMessageBox(false);
         job->start();
     }
@@ -116,7 +117,8 @@ QWidget *FilterActionAddToAddressBook::createParamWidget(QWidget *parent) const
     QWidget *widget = new QWidget(parent);
     QGridLayout *layout = new QGridLayout(widget);
 
-    PimCommon::MinimumComboBox *headerCombo = new PimCommon::MinimumComboBox(widget);
+    const auto headerCombo = new KComboBox(widget);
+    headerCombo->setMinimumWidth(50);
     headerCombo->setObjectName(QStringLiteral("HeaderComboBox"));
     layout->addWidget(headerCombo, 0, 0, 2, 1, Qt::AlignVCenter);
 
@@ -124,7 +126,7 @@ QWidget *FilterActionAddToAddressBook::createParamWidget(QWidget *parent) const
     label->setObjectName(QStringLiteral("label_with_category"));
     layout->addWidget(label, 0, 1);
 
-    KPIM::TagWidget *categoryEdit = new KPIM::TagWidget(widget);
+    auto categoryEdit = new Akonadi::TagWidget(widget);
     categoryEdit->setObjectName(QStringLiteral("CategoryEdit"));
     layout->addWidget(categoryEdit, 0, 2);
 
@@ -140,20 +142,40 @@ QWidget *FilterActionAddToAddressBook::createParamWidget(QWidget *parent) const
     collectionComboBox->setToolTip(i18n("This defines the preferred address book.\n"
                                         "If it is not accessible, the filter will fallback to the default address book."));
     layout->addWidget(collectionComboBox, 1, 2);
-
-    connect(headerCombo, QOverload<int>::of(&PimCommon::MinimumComboBox::currentIndexChanged), this, &FilterActionAddToAddressBook::filterActionModified);
+    connect(headerCombo, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &FilterActionAddToAddressBook::filterActionModified);
     connect(collectionComboBox, QOverload<int>::of(&Akonadi::CollectionComboBox::activated), this, &FilterActionAddToAddressBook::filterActionModified);
-    connect(categoryEdit, SIGNAL(selectionChanged(QStringList)),
-            this, SIGNAL(filterActionModified()));
+    connect(categoryEdit, &Akonadi::TagWidget::selectionChanged, this, &FilterActionAddToAddressBook::filterActionModified);
 
     setParamWidgetValue(widget);
 
     return widget;
 }
 
+namespace {
+
+Akonadi::Tag::List namesToTags(const QStringList &names)
+{
+    Akonadi::Tag::List tags;
+    tags.reserve(names.size());
+    std::transform(names.cbegin(), names.cend(), std::back_inserter(tags),
+                   [](const QString &name) { return Akonadi::Tag{name}; });
+    return tags;
+}
+
+QStringList tagsToNames(const Akonadi::Tag::List &tags)
+{
+    QStringList names;
+    names.reserve(tags.size());
+    std::transform(tags.cbegin(), tags.cend(), std::back_inserter(names),
+                   std::bind(&Akonadi::Tag::name, std::placeholders::_1));
+    return names;
+}
+
+}
+
 void FilterActionAddToAddressBook::setParamWidgetValue(QWidget *paramWidget) const
 {
-    PimCommon::MinimumComboBox *headerCombo = paramWidget->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("HeaderComboBox"));
+    const auto headerCombo = paramWidget->findChild<KComboBox *>(QStringLiteral("HeaderComboBox"));
     Q_ASSERT(headerCombo);
     headerCombo->clear();
     headerCombo->addItem(mFromStr, FromHeader);
@@ -163,9 +185,9 @@ void FilterActionAddToAddressBook::setParamWidgetValue(QWidget *paramWidget) con
 
     headerCombo->setCurrentIndex(headerCombo->findData(mHeaderType));
 
-    KPIM::TagWidget *categoryEdit = paramWidget->findChild<KPIM::TagWidget *>(QStringLiteral("CategoryEdit"));
+    auto categoryEdit = paramWidget->findChild<Akonadi::TagWidget *>(QStringLiteral("CategoryEdit"));
     Q_ASSERT(categoryEdit);
-    categoryEdit->setSelection(mCategory.split(QLatin1Char(';')));
+    categoryEdit->setSelection(namesToTags(mCategory.split(QLatin1Char(';'))));
 
     Akonadi::CollectionComboBox *collectionComboBox = paramWidget->findChild<Akonadi::CollectionComboBox *>(QStringLiteral("AddressBookComboBox"));
     Q_ASSERT(collectionComboBox);
@@ -175,13 +197,13 @@ void FilterActionAddToAddressBook::setParamWidgetValue(QWidget *paramWidget) con
 
 void FilterActionAddToAddressBook::applyParamWidgetValue(QWidget *paramWidget)
 {
-    const PimCommon::MinimumComboBox *headerCombo = paramWidget->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("HeaderComboBox"));
+    const auto headerCombo = paramWidget->findChild<QComboBox *>(QStringLiteral("HeaderComboBox"));
     Q_ASSERT(headerCombo);
     mHeaderType = static_cast<HeaderType>(headerCombo->itemData(headerCombo->currentIndex()).toInt());
 
-    const KPIM::TagWidget *categoryEdit = paramWidget->findChild<KPIM::TagWidget *>(QStringLiteral("CategoryEdit"));
+    const auto categoryEdit = paramWidget->findChild<Akonadi::TagWidget *>(QStringLiteral("CategoryEdit"));
     Q_ASSERT(categoryEdit);
-    mCategory = categoryEdit->selection().join(QLatin1Char(';'));
+    mCategory = tagsToNames(categoryEdit->selection()).join(QLatin1Char(';'));
 
     const Akonadi::CollectionComboBox *collectionComboBox = paramWidget->findChild<Akonadi::CollectionComboBox *>(QStringLiteral("AddressBookComboBox"));
     Q_ASSERT(collectionComboBox);
@@ -191,7 +213,7 @@ void FilterActionAddToAddressBook::applyParamWidgetValue(QWidget *paramWidget)
     // we use the previously 'stored' value from the 'collectionId' property
     if (collection.isValid()) {
         mCollectionId = collection.id();
-        connect(collectionComboBox, QOverload< int>::of(&Akonadi::CollectionComboBox::currentIndexChanged), this, &FilterActionAddToAddressBook::filterActionModified);
+        connect(collectionComboBox, QOverload<int>::of(&Akonadi::CollectionComboBox::currentIndexChanged), this, &FilterActionAddToAddressBook::filterActionModified);
     } else {
         const QVariant value = collectionComboBox->property("collectionId");
         if (value.isValid()) {
@@ -202,13 +224,13 @@ void FilterActionAddToAddressBook::applyParamWidgetValue(QWidget *paramWidget)
 
 void FilterActionAddToAddressBook::clearParamWidget(QWidget *paramWidget) const
 {
-    PimCommon::MinimumComboBox *headerCombo = paramWidget->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("HeaderComboBox"));
+    const auto headerCombo = paramWidget->findChild<QComboBox *>(QStringLiteral("HeaderComboBox"));
     Q_ASSERT(headerCombo);
     headerCombo->setCurrentIndex(0);
 
-    KPIM::TagWidget *categoryEdit = paramWidget->findChild<KPIM::TagWidget *>(QStringLiteral("CategoryEdit"));
+    auto categoryEdit = paramWidget->findChild<Akonadi::TagWidget *>(QStringLiteral("CategoryEdit"));
     Q_ASSERT(categoryEdit);
-    categoryEdit->setSelection(mCategory.split(QLatin1Char(';')));
+    categoryEdit->setSelection(namesToTags(mCategory.split(QLatin1Char(';'))));
 }
 
 QString FilterActionAddToAddressBook::argsAsString() const
@@ -242,7 +264,11 @@ QString FilterActionAddToAddressBook::argsAsString() const
 
 void FilterActionAddToAddressBook::argsFromString(const QString &argsStr)
 {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const QStringList parts = argsStr.split(QLatin1Char('\t'), QString::KeepEmptyParts);
+#else
+    const QStringList parts = argsStr.split(QLatin1Char('\t'), Qt::KeepEmptyParts);
+#endif
     const QString firstElement = parts[ 0 ];
     if (firstElement == QLatin1String("From")) {
         mHeaderType = FromHeader;
