@@ -1,10 +1,11 @@
 /*
 
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -26,14 +27,14 @@ class FilterActionUnsetStatus : public FilterActionStatus
     Q_OBJECT
 public:
     explicit FilterActionUnsetStatus(QObject *parent = nullptr);
-    ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
-    SearchRule::RequiredPart requiredPart() const override;
+    Q_REQUIRED_RESULT ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart() const override;
 
     static FilterAction *newAction();
-    QString sieveCode() const override;
-    QStringList sieveRequires() const override;
-    bool isEmpty() const override;
-    QString informationAboutNotValidAction() const override;
+    Q_REQUIRED_RESULT QString sieveCode() const override;
+    Q_REQUIRED_RESULT QStringList sieveRequires() const override;
+    Q_REQUIRED_RESULT bool isEmpty() const override;
+    Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
 private:
     bool checkIsValid(int &index) const;
 };
