@@ -25,7 +25,7 @@
 #include "mailcommon_export.h"
 
 #include <Libkdepim/KWidgetLister>
-
+#include <QVector>
 namespace MailCommon {
 class FilterAction;
 class FilterActionWidget;
@@ -83,7 +83,7 @@ public:
      * change during editing. Therefore the widget always creates a new
      * action object from the data in the combo box and returns that.
      */
-    MailCommon::FilterAction *action() const;
+    Q_REQUIRED_RESULT MailCommon::FilterAction *action() const;
 
     void updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled);
 
@@ -120,12 +120,12 @@ public:
     /**
      * Destroys the filter action widget lister.
      */
-    virtual ~FilterActionWidgetLister();
+    ~FilterActionWidgetLister() override;
 
     /**
      * Sets the @p list of filter actions, the lister will create FilterActionWidgets for.
      */
-    void setActionList(QList<MailCommon::FilterAction *> *list);
+    void setActionList(QVector<FilterAction *> *list);
 
     /**
      * Updates the action list according to the current action widget values.
