@@ -32,7 +32,7 @@ class FilterActionWithCrypto : public FilterAction
 protected:
     using FilterAction::FilterAction;
 
-    QStringList getEncryptionKeysFromContent(const KMime::Message::Ptr &msg, GpgME::Protocol proto) const;
+    Q_REQUIRED_RESULT QStringList getEncryptionKeysFromContent(const KMime::Message::Ptr &msg, GpgME::Protocol proto) const;
 
 private:
     // cached values
