@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +21,6 @@
 
 #include <KSyntaxHighlighting/Repository>
 #include <QDialog>
-
 namespace KPIMTextEdit {
 class PlainTextEditorWidget;
 }
@@ -41,6 +41,8 @@ private Q_SLOTS:
 private:
     void readConfig();
     void writeConfig();
+    void slotShareActionFinished(const QJsonObject &output, int error, const QString &message);
+    void slotInitializeShareMenu();
     KPIMTextEdit::PlainTextEditorWidget *mEditor = nullptr;
     KSyntaxHighlighting::Repository mSyntaxRepo;
 };
