@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2017 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,6 +24,10 @@
 #include <AkonadiCore/Collection>
 #include "mailcommon_export.h"
 namespace MailCommon {
+/**
+ * @brief The FilterImporterPathCache class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MAILCOMMON_EXPORT FilterImporterPathCache : public QObject
 {
     Q_OBJECT
@@ -33,9 +38,9 @@ public:
     ~FilterImporterPathCache();
 
     void insert(const QString &original, const Akonadi::Collection &newValue);
-    Akonadi::Collection convertedFilterPath(const QString &original);
+    Q_REQUIRED_RESULT Akonadi::Collection convertedFilterPath(const QString &original);
     void clear();
-    int count() const;
+    Q_REQUIRED_RESULT int count() const;
 private:
     QHash<QString, Akonadi::Collection> mFilterCache;
 };
