@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ FilterSelectionDialog::FilterSelectionDialog(QWidget *parent)
 {
     setObjectName(QStringLiteral("filterselection"));
     setModal(true);
-    setWindowTitle(i18n("Select Filters"));
+    setWindowTitle(i18nc("@title:window", "Select Filters"));
     QVBoxLayout *top = new QVBoxLayout(this);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
