@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 #include <QDialog>
 
-#include <QList>
+#include <QVector>
 
 class QPushButton;
 
@@ -38,8 +38,8 @@ class FilterSelectionDialog : public QDialog
 public:
     explicit FilterSelectionDialog(QWidget *parent = nullptr);
     ~FilterSelectionDialog() override;
-    void setFilters(const QList<MailFilter *> &filters);
-    QList<MailFilter *> selectedFilters() const;
+    void setFilters(const QVector<MailFilter *> &filters);
+    QVector<MailFilter *> selectedFilters() const;
 
 public Q_SLOTS:
     void slotUnselectAllButton();
@@ -50,7 +50,7 @@ private:
     void writeConfig();
     void readConfig();
     QListWidget *filtersListWidget = nullptr;
-    QList<MailFilter *> originalFilters;
+    QVector<MailFilter *> originalFilters;
     QPushButton *selectAllButton = nullptr;
     QPushButton *unselectAllButton = nullptr;
     QPushButton *mOkButton = nullptr;
