@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -27,15 +28,15 @@ public:
     InvalidFilterInfo();
     InvalidFilterInfo(const QString &name, const QString &information);
 
-    QString information() const;
+    Q_REQUIRED_RESULT QString information() const;
 
-    QString name() const;
+    Q_REQUIRED_RESULT QString name() const;
 
     void setName(const QString &name);
 
     void setInformation(const QString &information);
 
-    bool operator ==(const InvalidFilterInfo &other) const;
+    Q_REQUIRED_RESULT bool operator ==(const InvalidFilterInfo &other) const;
 private:
     QString mName;
     QString mInformation;
