@@ -3,7 +3,7 @@
   Author: Marc Mutz <mutz@kde.org>
   based upon work by Stefan Taferner <taferner@kde.org>
 
-  Copyright (c) 2011-2015 Laurent Montel <montel@kde.org>
+  Copyright (c) 2011-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -40,7 +40,6 @@ class KKeySequenceWidget;
 
 class QCheckBox;
 class QLabel;
-class QListWidget;
 class QPushButton;
 class QRadioButton;
 class QPushButton;
@@ -249,7 +248,7 @@ protected:
     QPushButton *mRunNow = nullptr;
     QPushButton *mApplyButton = nullptr;
     bool mDoNotClose = false;
-    bool mIgnoreFilterUpdates = false;
+    bool mIgnoreFilterUpdates = true;
 };
 }
 
