@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include "invalidfilters/invalidfilterinfo.h"
 #include "invalidfilters/invalidfilterdialog.h"
 #include <KLocalizedString>
-#include <klistwidgetsearchline.h>
+#include <KListWidgetSearchLine>
 #include <QPushButton>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -113,7 +113,7 @@ using namespace MailCommon;
 KMFilterListBox::KMFilterListBox(const QString &title, QWidget *parent)
     : QGroupBox(title, parent)
 {
-    QVBoxLayout *layout = new QVBoxLayout();
+    QVBoxLayout *layout = new QVBoxLayout(this);
 
     //----------- the list box
     mListWidget = new QListWidget(this);
@@ -202,7 +202,6 @@ KMFilterListBox::KMFilterListBox(const QString &title, QWidget *parent)
     mBtnRename->setWhatsThis(i18n(_wt_filterlist_rename));
 
     layout->addWidget(hb);
-    setLayout(layout);
 
     QShortcut *shortcut = new QShortcut(this);
     shortcut->setKey(Qt::Key_Delete);
@@ -287,8 +286,7 @@ void KMFilterListBox::createFilter(const QByteArray &field, const QString &value
     MailFilter *newFilter = new MailFilter();
     newFilter->pattern()->append(newRule);
     newFilter->pattern()->setName(QStringLiteral("<%1>: %2").
-                                  arg(QString::fromLatin1(field)).
-                                  arg(value));
+                                  arg(QString::fromLatin1(field), value));
 
     FilterActionDesc *desc = MailCommon::FilterManager::filterActionDict()->value(QStringLiteral("transfer"));
     if (desc) {
@@ -858,7 +856,6 @@ void KMFilterListBox::swapNeighbouringFilters(int untouchedOne, int movedOne)
 
 QListWidgetFilterItem::QListWidgetFilterItem(const QString &text, QListWidget *parent)
     : QListWidgetItem(text, parent)
-    , mFilter(nullptr)
 {
 }
 
