@@ -37,9 +37,9 @@ using MailCommon::FilterLog;
 
 // other KDE headers
 #include <KLocalizedString>
-#include <kmessagebox.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KMessageBox>
+#include <KConfig>
+#include <KConfigGroup>
 #include <krandom.h>
 #include <QPointer>
 
@@ -137,8 +137,6 @@ QString MailFilter::name() const
 
 MailFilter::ReturnCode MailFilter::execActions(ItemContext &context, bool &stopIt, bool applyOnOutbound) const
 {
-    ReturnCode status = NoResult;
-
     QVector<FilterAction *>::const_iterator it(mActions.constBegin());
     QVector<FilterAction *>::const_iterator end(mActions.constEnd());
     for (; it != end; ++it) {
@@ -148,7 +146,7 @@ MailFilter::ReturnCode MailFilter::execActions(ItemContext &context, bool &stopI
             FilterLog::instance()->add(logText, FilterLog::AppliedAction);
         }
 
-        FilterAction::ReturnCode result = (*it)->process(context, applyOnOutbound);
+        const FilterAction::ReturnCode result = (*it)->process(context, applyOnOutbound);
 
         switch (result) {
         case FilterAction::CriticalError:
@@ -171,13 +169,9 @@ MailFilter::ReturnCode MailFilter::execActions(ItemContext &context, bool &stopI
         }
     }
 
-    if (status == NoResult) { // No filters matched, keep copy of message
-        status = GoOn;
-    }
-
     stopIt = stopProcessingHere();
 
-    return status;
+    return GoOn;
 }
 
 QVector<FilterAction *> *MailFilter::actions()
@@ -648,7 +642,7 @@ const QString MailFilter::asString() const
     result += QLatin1String("Filter name: ") + name() + QLatin1String(" (") + mIdentifier  + QLatin1String(")\n");
     result += mPattern.asString() + QLatin1Char('\n');
 
-    result += QString("Filter is %1\n").arg(bEnabled ? QStringLiteral("enabled") : QStringLiteral("disabled"));
+    result += QStringLiteral("Filter is %1\n").arg(bEnabled ? QStringLiteral("enabled") : QStringLiteral("disabled"));
 
     QVector<FilterAction *>::const_iterator it(mActions.constBegin());
     QVector<FilterAction *>::const_iterator end(mActions.constEnd());
