@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -41,7 +42,7 @@ using namespace MailCommon;
 struct InstanceStruct {
     QString name;
     QIcon icon;
-    bool isValid() const
+    Q_REQUIRED_RESULT bool isValid() const
     {
         return !name.isEmpty();
     }
@@ -51,10 +52,6 @@ class MailCommon::AccountConfigOrderDialogPrivate
 {
 public:
     AccountConfigOrderDialogPrivate()
-        : mListAccount(nullptr)
-        , mUpButton(nullptr)
-        , mDownButton(nullptr)
-        , mEnableAccountOrder(nullptr)
     {
     }
 
@@ -70,7 +67,7 @@ AccountConfigOrderDialog::AccountConfigOrderDialog(MailCommon::MailCommonSetting
     , d(new MailCommon::AccountConfigOrderDialogPrivate)
 {
     d->mSettings = settings;
-    setWindowTitle(i18n("Edit Accounts Order"));
+    setWindowTitle(i18nc("@title:window", "Edit Accounts Order"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
@@ -84,7 +81,7 @@ AccountConfigOrderDialog::AccountConfigOrderDialog(MailCommon::MailCommonSetting
     mainLayout->addWidget(buttonBox);
 
     QVBoxLayout *vbox = new QVBoxLayout;
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
     page->setLayout(vbox);
 
     d->mEnableAccountOrder = new QCheckBox(i18n("Use custom order"), this);
@@ -100,7 +97,7 @@ AccountConfigOrderDialog::AccountConfigOrderDialog(MailCommon::MailCommonSetting
 
     QWidget *upDownBox = new QWidget(page);
     QVBoxLayout *upDownBoxVBoxLayout = new QVBoxLayout(upDownBox);
-    upDownBoxVBoxLayout->setMargin(0);
+    upDownBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
     d->mUpButton = new QPushButton(upDownBox);
     upDownBoxVBoxLayout->addWidget(d->mUpButton);
     d->mUpButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
@@ -194,32 +191,26 @@ void AccountConfigOrderDialog::init()
     QMap<QString, InstanceStruct> mapInstance;
     const Akonadi::AgentInstance::List lstInstances = Akonadi::AgentManager::self()->instances();
     for (const Akonadi::AgentInstance &instance : lstInstances) {
-        const QStringList capabilities(instance.type().capabilities());
-        if (instance.type().mimeTypes().contains(KMime::Message::mimeType())) {
-            if (capabilities.contains(QStringLiteral("Resource"))
-                && !capabilities.contains(QStringLiteral("Virtual"))
-                && !capabilities.contains(QStringLiteral("MailTransport"))) {
-                const QString identifier = instance.identifier();
-                if (!identifier.contains(POP3_RESOURCE_IDENTIFIER)) {
-                    instanceList << instance.identifier();
-                    InstanceStruct instanceStruct;
-                    instanceStruct.name = instance.name();
-                    if (PimCommon::Util::isImapResource(identifier)) {
-                        instanceStruct.name += QLatin1String(" (IMAP)");
-                    } else if (identifier.startsWith(QStringLiteral("akonadi_maildir_resource"))) {
-                        instanceStruct.name += QLatin1String(" (Maildir)");
-                    } else if (identifier.startsWith(QStringLiteral("akonadi_mailbox_resource"))) {
-                        instanceStruct.name += QLatin1String(" (Mailbox)");
-                    } else if (identifier.startsWith(QStringLiteral("akonadi_mixedmaildir_resource"))) {
-                        instanceStruct.name += QLatin1String(" (Mixedmaildir)");
-                    } else {
-                        qCDebug(MAILCOMMON_LOG) << " Unknown resource type " << identifier;
-                    }
-                    instanceStruct.icon = instance.type().icon();
-                    mapInstance.insert(instance.identifier(), instanceStruct);
-                }
-            }
+        const QString identifier = instance.identifier();
+        if (!MailCommon::Util::isMailAgent(instance) || identifier.contains(POP3_RESOURCE_IDENTIFIER)) {
+            continue;
         }
+        instanceList << instance.identifier();
+        InstanceStruct instanceStruct;
+        instanceStruct.name = instance.name();
+        if (PimCommon::Util::isImapResource(identifier)) {
+            instanceStruct.name += QLatin1String(" (IMAP)");
+        } else if (identifier.startsWith(QLatin1String("akonadi_maildir_resource"))) {
+            instanceStruct.name += QLatin1String(" (Maildir)");
+        } else if (identifier.startsWith(QLatin1String("akonadi_mailbox_resource"))) {
+            instanceStruct.name += QLatin1String(" (Mailbox)");
+        } else if (identifier.startsWith(QLatin1String("akonadi_mixedmaildir_resource"))) {
+            instanceStruct.name += QLatin1String(" (Mixedmaildir)");
+        } else {
+            qCDebug(MAILCOMMON_LOG) << " Unknown resource type " << identifier;
+        }
+        instanceStruct.icon = instance.type().icon();
+        mapInstance.insert(instance.identifier(), instanceStruct);
     }
     instanceList.sort(Qt::CaseInsensitive);
     const int numberOfList(listOrderAccount.count());
