@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -121,6 +121,9 @@ public:
     Q_REQUIRED_RESULT MessageViewer::Viewer::DisplayFormatMessage formatMessage() const;
     void setFormatMessage(MessageViewer::Viewer::DisplayFormatMessage formatMessage);
 
+    Q_REQUIRED_RESULT bool folderHtmlLoadExtPreference() const;
+    void setFolderHtmlLoadExtPreference(bool folderHtmlLoadExtPreference);
+
 protected Q_SLOTS:
     void slotIdentitiesChanged();
 
@@ -144,6 +147,8 @@ private:
     /** Should this folder be hidden in the folder selection dialog? */
     bool mHideInSelectionDialog = false;
 
+    bool mFolderHtmlLoadExtPreference = false;
+
     /** shortcut associated with this folder or null, if none is configured. */
     QKeySequence mShortcut;
     bool mWriteConfig;
