@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -577,7 +577,7 @@ Akonadi::Collection FolderTreeView::currentFolder() const
 
 void FolderTreeView::mousePressEvent(QMouseEvent *e)
 {
-    const bool buttonPressedIsMiddle = (e->button() == Qt::MidButton);
+    const bool buttonPressedIsMiddle = (e->button() == Qt::MiddleButton);
     Q_EMIT newTabRequested(buttonPressedIsMiddle);
     EntityTreeView::mousePressEvent(e);
 }
