@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2019 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -76,7 +76,7 @@ public:
 
     QColor brokenAccountColor;
     qreal threshold = 0.0;
-    FolderTreeWidgetProxyModel *q;
+    FolderTreeWidgetProxyModel * const q;
     bool enableCheck = false;
     bool hideVirtualFolder = false;
     bool hideSpecificFolder = false;
@@ -126,7 +126,7 @@ Qt::ItemFlags FolderTreeWidgetProxyModel::flags(const QModelIndex &index) const
         if (!MailCommon::Util::isVirtualCollection(collection)) {
             const Akonadi::AgentInstance instance = Akonadi::AgentManager::self()->instance(collection.resource());
             if (instance.status() == Akonadi::AgentInstance::Broken) {
-                return KRecursiveFilterProxyModel::flags(sourceIndex) & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+                return QSortFilterProxyModel::flags(sourceIndex) & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
             }
         }
         return Akonadi::EntityRightsFilterModel::flags(index);
@@ -190,7 +190,7 @@ bool FolderTreeWidgetProxyModel::hideOutboxFolder() const
     return d->hideOutboxFolder;
 }
 
-bool FolderTreeWidgetProxyModel::acceptRow(int sourceRow, const QModelIndex &sourceParent) const
+bool FolderTreeWidgetProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
     const QModelIndex modelIndex = sourceModel()->index(sourceRow, 0, sourceParent);
 
@@ -221,7 +221,7 @@ bool FolderTreeWidgetProxyModel::acceptRow(int sourceRow, const QModelIndex &sou
         }
     }
 
-    return KRecursiveFilterProxyModel::acceptRow(sourceRow, sourceParent);
+    return EntityRightsFilterModel::filterAcceptsRow(sourceRow, sourceParent);
 }
 
 QVariant FolderTreeWidgetProxyModel::data(const QModelIndex &index, int role) const
