@@ -21,7 +21,7 @@
 
 #include "backupjob.h"
 
-#include <Libkdepim/BroadcastStatus>
+#include <PimCommon/BroadcastStatus>
 #include "mailcommon_debug.h"
 #include <CollectionDeleteJob>
 #include <CollectionFetchJob>
@@ -35,7 +35,7 @@
 #include <KMessageBox>
 #include <KTar>
 #include <KZip>
-#include <kio/global.h> //krazy:exclude=camelcase as there is no such
+#include <KIO/Global>
 
 #include <QFileInfo>
 #include <QTimer>
@@ -46,19 +46,9 @@ static const mode_t archivePerms = S_IFREG | 0644;
 BackupJob::BackupJob(QWidget *parent)
     : QObject(parent)
     , mArchiveTime(QDateTime::currentDateTime())
-    , mArchiveType(Zip)
     , mRootFolder(0)
-    , mArchive(nullptr)
     , mParentWidget(parent)
-    , mArchivedMessages(0)
-    , mArchivedSize(0)
-    , mProgressItem(nullptr)
-    , mAborted(false)
-    , mDeleteFoldersAfterCompletion(false)
-    , mRecursive(true)
     , mCurrentFolder(Akonadi::Collection())
-    , mCurrentJob(nullptr)
-    , mDisplayMessageBox(true)
 {
 }
 
@@ -193,7 +183,7 @@ void BackupJob::finish()
     }
 
     const QString archivingStr(i18n("Archiving finished"));
-    KPIM::BroadcastStatus::instance()->setStatusMsg(archivingStr);
+    PimCommon::BroadcastStatus::instance()->setStatusMsg(archivingStr);
 
     if (mProgressItem) {
         mProgressItem->setStatus(archivingStr);
@@ -237,8 +227,7 @@ void BackupJob::archiveNextMessage()
         return;
     }
 
-    Akonadi::Item item = mPendingMessages.front();
-    mPendingMessages.pop_front();
+    const Akonadi::Item item = mPendingMessages.takeFirst();
     qCDebug(MAILCOMMON_LOG) << "Fetching item with ID" << item.id() << "for folder" << mCurrentFolder.name();
 
     mCurrentJob = new Akonadi::ItemFetchJob(item);
@@ -357,7 +346,7 @@ void BackupJob::archiveNextFolder()
     if (mProgressItem) {
         mProgressItem->setStatus(archivingStr);
     }
-    KPIM::BroadcastStatus::instance()->setStatusMsg(archivingStr);
+    PimCommon::BroadcastStatus::instance()->setStatusMsg(archivingStr);
 
     const QString folderName = mCurrentFolder.name();
     bool success = true;
