@@ -31,8 +31,8 @@
 #include "kernel/mailkernel.h"
 #include "util/mailutil.h"
 
-#include <Libkdepim/BroadcastStatus>
-using KPIM::BroadcastStatus;
+#include <PimCommon/BroadcastStatus>
+using PimCommon::BroadcastStatus;
 #include "mailcommon_debug.h"
 
 #include <KLocalizedString>
@@ -63,9 +63,6 @@ using KPIM::BroadcastStatus;
 namespace MailCommon {
 ExpireJob::ExpireJob(const Akonadi::Collection &folder, bool immediate)
     : ScheduledJob(folder, immediate)
-    , mMaxUnreadTime(0)
-    , mMaxReadTime(0)
-    , mMoveToFolder(0)
 {
 }
 
@@ -83,10 +80,10 @@ void ExpireJob::execute()
 {
     mMaxUnreadTime = 0;
     mMaxReadTime = 0;
-    int unreadDays, readDays;
 
     const MailCommon::ExpireCollectionAttribute *expirationAttribute = mSrcFolder.attribute<MailCommon::ExpireCollectionAttribute>();
     if (expirationAttribute) {
+        int unreadDays, readDays;
         expirationAttribute->daysToExpire(unreadDays, readDays);
 
         if (unreadDays > 0) {
