@@ -175,9 +175,9 @@ void SearchPattern::importLegacyConfig(const KConfigGroup &config)
 {
     SearchRule::Ptr rule
         = SearchRule::createInstance(
-        config.readEntry("fieldA").toLatin1(),
-        config.readEntry("funcA").toLatin1().constData(),
-        config.readEntry("contentsA"));
+              config.readEntry("fieldA").toLatin1(),
+              config.readEntry("funcA").toLatin1().constData(),
+              config.readEntry("contentsA"));
 
     if (rule->isEmpty()) {
         // if the first rule is invalid,
@@ -193,9 +193,9 @@ void SearchPattern::importLegacyConfig(const KConfigGroup &config)
 
     rule
         = SearchRule::createInstance(
-        config.readEntry("fieldB").toLatin1(),
-        config.readEntry("funcB").toLatin1().constData(),
-        config.readEntry("contentsB"));
+              config.readEntry("fieldB").toLatin1(),
+              config.readEntry("funcB").toLatin1().constData(),
+              config.readEntry("contentsB"));
 
     if (rule->isEmpty()) {
         return;
@@ -283,7 +283,7 @@ QString SearchPattern::asString() const
     QList<SearchRule::Ptr>::const_iterator it;
     QList<SearchRule::Ptr>::const_iterator endIt = constEnd();
     for (it = constBegin(); it != endIt; ++it) {
-        result += QStringLiteral("\n\t") + FilterLog::recode((*it)->asString());
+        result += QLatin1String("\n\t") + FilterLog::recode((*it)->asString());
     }
 
     return result;
@@ -366,7 +366,7 @@ QDataStream &SearchPattern::operator>>(QDataStream &s) const
         break;
     }
 
-    Q_FOREACH (const SearchRule::Ptr rule, *this) {
+    for (const SearchRule::Ptr rule : qAsConst(*this)) {
         *rule >> s;
     }
     return s;
@@ -391,7 +391,7 @@ QDataStream &SearchPattern::operator<<(QDataStream &s)
     return s;
 }
 
-void SearchPattern::generateSieveScript(QStringList &requires, QString &code)
+void SearchPattern::generateSieveScript(QStringList &requiresModules, QString &code)
 {
     code += QLatin1String("\n#") + mName + QLatin1Char('\n');
     switch (mOperator) {
@@ -413,7 +413,7 @@ void SearchPattern::generateSieveScript(QStringList &requires, QString &code)
         if (i != 0) {
             code += QLatin1String("\n, ");
         }
-        (*it)->generateSieveScript(requires, code);
+        (*it)->generateSieveScript(requiresModules, code);
     }
 }
 
