@@ -21,20 +21,18 @@
 #include "widgethandler/rulewidgethandlermanager.h"
 using MailCommon::RuleWidgetHandlerManager;
 #include "mailcommon_debug.h"
-#include <PimCommon/MinimumComboBox>
 
-#include <QDialog>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <KLocalizedString>
 #include <QPushButton>
-#include <KLineEdit>
+#include <QLineEdit>
 #include <QIcon>
-
+#include <KComboBox>
 #include <QButtonGroup>
 #include <QByteArray>
 #include <QHBoxLayout>
 #include <QRadioButton>
 #include <QStackedWidget>
-#include <KConfigGroup>
 
 // Definition of special rule field strings
 // Note: Also see SearchRule::matches() and ruleFieldToEnglish() if
@@ -43,9 +41,7 @@ using MailCommon::RuleWidgetHandlerManager;
 //       the value of the entries in the enum in SearchRuleWidget.
 
 #undef I18N_NOOP
-#define I18N_NOOP(t) 0, t
-#undef I18N_NOOP2
-#define I18N_NOOP2(c,t) c, t
+#define I18N_NOOP(t) nullptr, t
 
 using namespace MailCommon;
 
@@ -58,26 +54,26 @@ static const struct {
     {
         return i18nc(context, displayName);
     }
-
 } SpecialRuleFields[] = {
-    { "<message>",     I18N_NOOP("Complete Message")       },
-    { "<body>",        I18N_NOOP("Body of Message")          },
-    { "<any header>",  I18N_NOOP("Anywhere in Headers")    },
-    { "<recipients>",  I18N_NOOP("All Recipients")    },
-    { "<size>",        I18N_NOOP("Size in Bytes") },
+    { "<message>", I18N_NOOP("Complete Message")       },
+    { "<body>", I18N_NOOP("Body of Message")          },
+    { "<any header>", I18N_NOOP("Anywhere in Headers")    },
+    { "<recipients>", I18N_NOOP("All Recipients")    },
+    { "<size>", I18N_NOOP("Size in Bytes") },
     { "<age in days>", I18N_NOOP("Age in Days")   },
-    { "<status>",      I18N_NOOP("Message Status")        },
-    { "<tag>",         I18N_NOOP("Message Tag") },
-    { "Subject",       I18N_NOOP2("Subject of an email.", "Subject")  },
-    { "From",          I18N_NOOP("From")  },
-    { "To",            I18N_NOOP2("Receiver of an email.", "To")  },
-    { "CC",            I18N_NOOP("CC")  },
-    { "Reply-To",      I18N_NOOP("Reply To")  },
-    { "Organization",  I18N_NOOP("Organization")  },
-    { "<date>",  I18N_NOOP("Date")  }
+    { "<status>", I18N_NOOP("Message Status")        },
+    { "<tag>", I18N_NOOP("Message Tag") },
+    { "Subject", I18NC_NOOP("Subject of an email.", "Subject")  },
+    { "From", I18N_NOOP("From")  },
+    { "To", I18NC_NOOP("Receiver of an email.", "To")  },
+    { "CC", I18N_NOOP("CC")  },
+    { "Reply-To", I18N_NOOP("Reply To")  },
+    { "Organization", I18N_NOOP("Organization")  },
+    { "<date>", I18N_NOOP("Date")  },
+    { "<encryption>", I18N_NOOP("Encryption") }
 };
-static const int SpecialRuleFieldsCount =
-    sizeof(SpecialRuleFields) / sizeof(*SpecialRuleFields);
+static const int SpecialRuleFieldsCount
+    = sizeof(SpecialRuleFields) / sizeof(*SpecialRuleFields);
 
 //=============================================================================
 //
@@ -85,13 +81,8 @@ static const int SpecialRuleFieldsCount =
 //
 //=============================================================================
 
-SearchRuleWidget::SearchRuleWidget(QWidget *parent, SearchRule::Ptr aRule,
-                                   SearchPatternEdit::SearchPatternEditOptions options,
-                                   SearchPatternEdit::SearchModeType modeType)
-    : QWidget(parent),
-      mRuleField(0),
-      mFunctionStack(0),
-      mValueStack(0)
+SearchRuleWidget::SearchRuleWidget(QWidget *parent, SearchRule::Ptr aRule, SearchPatternEdit::SearchPatternEditOptions options, SearchPatternEdit::SearchModeType modeType)
+    : QWidget(parent)
 {
     initFieldList(options);
     initWidget(modeType);
@@ -157,18 +148,19 @@ void SearchRuleWidget::setPatternEditOptions(SearchPatternEdit::SearchPatternEdi
 void SearchRuleWidget::initWidget(SearchPatternEdit::SearchModeType modeType)
 {
     QHBoxLayout *hlay = new QHBoxLayout(this);
-    hlay->setMargin(0);
+    hlay->setContentsMargins(0, 0, 0, 0);
 
     // initialize the header field combo box
-    mRuleField = new PimCommon::MinimumComboBox(this);
+    mRuleField = new KComboBox(this);
+    mRuleField->setMinimumWidth(50);
     mRuleField->setObjectName(QStringLiteral("mRuleField"));
     mRuleField->setEditable(true);
-    KLineEdit *edit = new KLineEdit;
+    QLineEdit *edit = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(edit, this);
     edit->setPlaceholderText(i18n("Choose or type your own criteria"));
     mRuleField->setToolTip(i18n("Choose or type your own criteria"));
     edit->setClearButtonEnabled(true);
     mRuleField->setLineEdit(edit);
-    mRuleField->setTrapReturnKey(true);
 
     mRuleField->addItems(mFilterFieldList);
     KCompletion *comp = mRuleField->completionObject();
@@ -202,15 +194,20 @@ void SearchRuleWidget::initWidget(SearchPatternEdit::SearchModeType modeType)
     mRemove->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
     hlay->addWidget(mRemove);
 
-    RuleWidgetHandlerManager::instance()->setIsBalooSearch(modeType == SearchPatternEdit::BalooMode);
+    RuleWidgetHandlerManager::instance()->setIsAkonadiSearch(modeType == SearchPatternEdit::BalooMode);
 
     RuleWidgetHandlerManager::instance()->createWidgets(mFunctionStack, mValueStack, this);
 
     // redirect focus to the header field combo box
     setFocusProxy(mRuleField);
 
-    connect(mRuleField, SIGNAL(activated(QString)),
-            this, SLOT(slotRuleFieldChanged(QString)));
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+    connect(mRuleField, QOverload<const QString &>::of(&QComboBox::activated),
+            this, &SearchRuleWidget::slotRuleFieldChanged);
+#else
+    connect(mRuleField, &QComboBox::textActivated,
+            this, &SearchRuleWidget::slotRuleFieldChanged);
+#endif
     connect(mRuleField, &QComboBox::editTextChanged,
             this, &SearchRuleWidget::slotRuleFieldChanged);
     connect(mRuleField, &QComboBox::editTextChanged,
@@ -266,11 +263,11 @@ SearchRule::Ptr SearchRuleWidget::rule() const
 {
     const QByteArray ruleField = ruleFieldToEnglish(mRuleField->currentText());
 
-    const SearchRule::Function function =
-        RuleWidgetHandlerManager::instance()->function(ruleField, mFunctionStack);
+    const SearchRule::Function function
+        = RuleWidgetHandlerManager::instance()->function(ruleField, mFunctionStack);
 
-    const QString value =
-        RuleWidgetHandlerManager::instance()->value(ruleField, mFunctionStack, mValueStack);
+    const QString value
+        = RuleWidgetHandlerManager::instance()->value(ruleField, mFunctionStack, mValueStack);
 
     return SearchRule::createInstance(ruleField, function, value);
 }
@@ -289,8 +286,8 @@ void SearchRuleWidget::slotFunctionChanged()
 {
     const QByteArray ruleField = ruleFieldToEnglish(mRuleField->currentText());
     RuleWidgetHandlerManager::instance()->update(ruleField, mFunctionStack, mValueStack);
-    const QString prettyValue =
-        RuleWidgetHandlerManager::instance()->prettyValue(ruleField, mFunctionStack, mValueStack);
+    const QString prettyValue
+        = RuleWidgetHandlerManager::instance()->prettyValue(ruleField, mFunctionStack, mValueStack);
 
     Q_EMIT contentsChanged(prettyValue);
 }
@@ -299,8 +296,8 @@ void SearchRuleWidget::slotValueChanged()
 {
     const QByteArray ruleField = ruleFieldToEnglish(mRuleField->currentText());
 
-    const QString prettyValue =
-        RuleWidgetHandlerManager::instance()->prettyValue(ruleField, mFunctionStack, mValueStack);
+    const QString prettyValue
+        = RuleWidgetHandlerManager::instance()->prettyValue(ruleField, mFunctionStack, mValueStack);
 
     Q_EMIT contentsChanged(prettyValue);
 }
@@ -396,6 +393,8 @@ void SearchRuleWidget::initFieldList(SearchPatternEdit::SearchPatternEditOptions
         mFilterFieldList.append(i18n(SpecialRuleFields[Date].displayName));
     }
 
+    mFilterFieldList.append(i18n(SpecialRuleFields[Encryption].displayName));
+
     // these others only represent message headers and you can add to
     // them as you like
     mFilterFieldList.append(QStringLiteral("List-Id"));
@@ -403,6 +402,7 @@ void SearchRuleWidget::initFieldList(SearchPatternEdit::SearchPatternEditOptions
     mFilterFieldList.append(QStringLiteral("X-Loop"));
     mFilterFieldList.append(QStringLiteral("X-Mailing-List"));
     mFilterFieldList.append(QStringLiteral("X-Spam-Flag"));
+    mFilterFieldList.append(QStringLiteral("X-Spam-Status"));
 }
 
 void SearchRuleWidget::slotRuleFieldChanged(const QString &field)
@@ -418,9 +418,9 @@ void SearchRuleWidget::slotRuleFieldChanged(const QString &field)
 //=============================================================================
 
 SearchRuleWidgetLister::SearchRuleWidgetLister(QWidget *parent, SearchPatternEdit::SearchPatternEditOptions options, SearchPatternEdit::SearchModeType modeType)
-    : KWidgetLister(false, 2, SearchPattern::filterRulesMaximumSize(), parent)
+    : KWidgetLister(false, 1, SearchPattern::filterRulesMaximumSize(), parent)
 {
-    mRuleList = 0;
+    mRuleList = nullptr;
 
     mTypeMode = modeType;
     mOptions = options;
@@ -433,7 +433,8 @@ SearchRuleWidgetLister::~SearchRuleWidgetLister()
 void SearchRuleWidgetLister::setPatternEditOptions(SearchPatternEdit::SearchPatternEditOptions options)
 {
     mOptions = options;
-    foreach (QWidget *w, widgets()) {
+    const auto lst = widgets();
+    for (QWidget *w : lst) {
         qobject_cast<SearchRuleWidget *>(w)->setPatternEditOptions(options);
     }
 }
@@ -449,12 +450,12 @@ void SearchRuleWidgetLister::setRuleList(QList<SearchRule::Ptr> *aList)
     mRuleList = aList;
 
     if (!widgets().isEmpty()) {   // move this below next 'if'?
-        widgets().first()->blockSignals(true);
+        widgets().constFirst()->blockSignals(true);
     }
 
     if (aList->isEmpty()) {
         slotClear();
-        widgets().first()->blockSignals(false);
+        widgets().constFirst()->blockSignals(false);
         return;
     }
 
@@ -477,7 +478,7 @@ void SearchRuleWidgetLister::setRuleList(QList<SearchRule::Ptr> *aList)
     QList<QWidget *>::const_iterator wIt = widgetList.constBegin();
     QList<QWidget *>::const_iterator wItEnd = widgetList.constEnd();
     for (rIt = mRuleList->constBegin();
-            rIt != rItEnd && wIt != wItEnd; ++rIt, ++wIt) {
+         rIt != rItEnd && wIt != wItEnd; ++rIt, ++wIt) {
         qobject_cast<SearchRuleWidget *>(*wIt)->setRule((*rIt));
     }
     for (; wIt != wItEnd; ++wIt) {
@@ -485,7 +486,7 @@ void SearchRuleWidgetLister::setRuleList(QList<SearchRule::Ptr> *aList)
     }
 
     Q_ASSERT(!widgets().isEmpty());
-    widgets().first()->blockSignals(false);
+    widgets().constFirst()->blockSignals(false);
     updateAddRemoveButton();
 }
 
@@ -539,15 +540,15 @@ void SearchRuleWidgetLister::reset()
         regenerateRuleListFromWidgets();
     }
 
-    mRuleList = 0;
+    mRuleList = nullptr;
     slotClear();
     updateAddRemoveButton();
 }
 
 QWidget *SearchRuleWidgetLister::createWidget(QWidget *parent)
 {
-    SearchRuleWidget *w =
-        new SearchRuleWidget(parent, SearchRule::Ptr(), mOptions, mTypeMode);
+    SearchRuleWidget *w
+        = new SearchRuleWidget(parent, SearchRule::Ptr(), mOptions, mTypeMode);
     reconnectWidget(w);
     return w;
 }
@@ -570,7 +571,8 @@ void SearchRuleWidgetLister::regenerateRuleListFromWidgets()
 
     mRuleList->clear();
 
-    foreach (const QWidget *w, widgets()) {
+    const auto lst = widgets();
+    for (const QWidget *w : lst) {
         SearchRule::Ptr r = qobject_cast<const SearchRuleWidget *>(w)->rule();
         if (r && !r->isEmpty()) {
             mRuleList->append(r);
@@ -586,7 +588,8 @@ void SearchRuleWidgetLister::regenerateRuleListFromWidgets()
 //=============================================================================
 
 SearchPatternEdit::SearchPatternEdit(QWidget *parent, SearchPatternEditOptions options, SearchModeType modeType)
-    : QWidget(parent), mAllMessageRBtn(0)
+    : QWidget(parent)
+    , mAllMessageRBtn(nullptr)
 {
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     setObjectName(QStringLiteral("SearchPatternEdit"));
@@ -610,7 +613,7 @@ void SearchPatternEdit::setPatternEditOptions(SearchPatternEdit::SearchPatternEd
 void SearchPatternEdit::initLayout(SearchPatternEditOptions options, SearchModeType modeType)
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     const bool matchAllMessages = (options & MailCommon::SearchPatternEdit::MatchAllMessages);
     //------------the radio buttons
@@ -642,13 +645,13 @@ void SearchPatternEdit::initLayout(SearchPatternEditOptions options, SearchModeT
     }
 
     //------------connect a few signals
-    connect(bg, SIGNAL(buttonClicked(QAbstractButton*)),
-            this, SLOT(slotRadioClicked(QAbstractButton*)));
+    connect(bg, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked),
+            this, &SearchPatternEdit::slotRadioClicked);
 
     //------------the list of SearchRuleWidget's
-    mRuleLister =
-        new SearchRuleWidgetLister(
-        this, options, modeType);
+    mRuleLister
+        = new SearchRuleWidgetLister(
+              this, options, modeType);
 
     mRuleLister->slotClear();
 
@@ -667,9 +670,9 @@ void SearchPatternEdit::initLayout(SearchPatternEditOptions options, SearchModeT
         qCDebug(MAILCOMMON_LOG) << "No first SearchRuleWidget, though slotClear() has been called!";
     }
 
-    connect(mRuleLister, SIGNAL(widgetAdded(QWidget*)),
-            this, SLOT(slotRuleAdded(QWidget*)));
-    connect(mRuleLister, SIGNAL(widgetRemoved()), this, SIGNAL(patternChanged()));
+    connect(mRuleLister, QOverload<QWidget *>::of(&SearchRuleWidgetLister::widgetAdded),
+            this, &SearchPatternEdit::slotRuleAdded);
+    connect(mRuleLister, QOverload<>::of(&SearchRuleWidgetLister::widgetRemoved), this, &SearchPatternEdit::patternChanged);
     connect(mRuleLister, &KPIM::KWidgetLister::clearWidgets, this, &SearchPatternEdit::patternChanged);
 
     layout->addWidget(mRuleLister);
