@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #include "mailcommon_debug.h"
 
 #include <KLocalizedString>
-#include <KLineEdit>
+#include <QLineEdit>
 #include <KMessageBox>
 #include <KJob>
 
@@ -34,8 +34,6 @@ class MailCommon::AddTagDialogPrivate
 {
 public:
     AddTagDialogPrivate()
-        : mTagWidget(nullptr)
-        , mOkButton(nullptr)
     {
     }
 
@@ -52,13 +50,13 @@ AddTagDialog::AddTagDialog(const QList<KActionCollection *> &actions, QWidget *p
     , d(new MailCommon::AddTagDialogPrivate)
 {
     setModal(true);
-    setWindowTitle(i18n("Add Tag"));
+    setWindowTitle(i18nc("@title:window", "Add Tag"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     d->mTagWidget = new MailCommon::TagWidget(actions, this);
     mainLayout->addWidget(d->mTagWidget);
 
-    connect(d->mTagWidget->tagNameLineEdit(), &KLineEdit::textChanged, this, &AddTagDialog::slotTagNameChanged);
+    connect(d->mTagWidget->tagNameLineEdit(), &QLineEdit::textChanged, this, &AddTagDialog::slotTagNameChanged);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->mOkButton = buttonBox->button(QDialogButtonBox::Ok);
