@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,33 +21,30 @@
 
 #include "mailcommon_export.h"
 #include "tag.h"
+#include <QVector>
 #include <QDialog>
 #include <AkonadiCore/Tag>
 #include <AkonadiCore/TagCreateJob>
-#include <KConfigGroup>
 
 class KActionCollection;
 
-namespace MailCommon
-{
+namespace MailCommon {
 class AddTagDialogPrivate;
 class MAILCOMMON_EXPORT AddTagDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit AddTagDialog(const QList<KActionCollection *> &actions, QWidget *parent = Q_NULLPTR);
+    explicit AddTagDialog(const QList<KActionCollection *> &actions, QWidget *parent = nullptr);
     ~AddTagDialog();
 
-    void setTags(const QList<MailCommon::Tag::Ptr> &tags);
-    QString label() const;
-    Akonadi::Tag tag() const;
+    void setTags(const QVector<MailCommon::Tag::Ptr> &tags);
+    Q_REQUIRED_RESULT QString label() const;
+    Q_REQUIRED_RESULT Akonadi::Tag tag() const;
 
-private Q_SLOTS:
+private:
     void slotSave();
     void slotTagNameChanged(const QString &text);
     void onTagCreated(KJob *job);
-
-private:
     AddTagDialogPrivate *const d;
 };
 }
