@@ -1,6 +1,6 @@
 /*
   Copyright (c) 2003 Andreas Gungl <a.gungl@gmx.de>
-  Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
+  Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -56,14 +56,7 @@ class Q_DECL_HIDDEN RedirectDialog::Private
 public:
     Private(RedirectDialog *qq, RedirectDialog::SendMode mode)
         : q(qq)
-        , mEditTo(nullptr)
-        , mEditCc(nullptr)
-        , mEditBcc(nullptr)
         , mSendMode(mode)
-        , mComboboxIdentity(nullptr)
-        , mTransportCombobox(nullptr)
-        , mUser1Button(nullptr)
-        , mUser2Button(nullptr)
     {
     }
 
@@ -77,7 +70,7 @@ public:
     void slotUser2();
     void slotAddressChanged(const QString &);
     QString redirectLabelType(TypeAddress type) const;
-    RedirectDialog *q = nullptr;
+    RedirectDialog * const q = nullptr;
     RedirectWidget *mEditTo = nullptr;
     RedirectWidget *mEditCc = nullptr;
     RedirectWidget *mEditBcc = nullptr;
@@ -129,7 +122,7 @@ RedirectDialog::RedirectDialog(SendMode mode, QWidget *parent)
     : QDialog(parent)
     , d(new Private(this, mode))
 {
-    setWindowTitle(i18n("Redirect Message"));
+    setWindowTitle(i18nc("@title:window", "Redirect Message"));
     QVBoxLayout *topLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel, this);
     d->mUser1Button = new QPushButton(this);
