@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,7 +22,6 @@
 #include "kernel/mailkernel.h"
 
 #include <QTreeView>
-#include <KIconLoader>
 #include <MessageComposer/ComposerLineEdit>
 
 #include <Akonadi/Contact/EmailAddressSelectionDialog>
@@ -39,7 +38,7 @@ RedirectWidget::RedirectWidget(QWidget *parent)
 {
     QHBoxLayout *hbox = new QHBoxLayout(this);
     hbox->setSpacing(0);
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
     hbox->setAlignment(Qt::AlignRight);
 
     mEdit = new MessageComposer::ComposerLineEdit(true);
@@ -50,7 +49,6 @@ RedirectWidget::RedirectWidget(QWidget *parent)
 
     QPushButton *BtnTo = new QPushButton(this);
     BtnTo->setIcon(QIcon::fromTheme(QStringLiteral("help-contents")));
-    BtnTo->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     BtnTo->setToolTip(i18n("Use the Address-Selection Dialog"));
     BtnTo->setWhatsThis(i18n("This button opens a separate dialog "
                              "where you can select recipients out "
@@ -100,7 +98,7 @@ void RedirectWidget::slotAddressSelection()
             addresses.prepend(mResendStr);
         }
 
-        mEdit->setText(addresses.join(QStringLiteral(", ")));
+        mEdit->setText(addresses.join(QLatin1String(", ")));
         mEdit->setModified(true);
     }
 }
